@@ -6,11 +6,11 @@ class RabbitConfig:
     def __init__(self,
                  host: str,
                  port: int,
-                 exchange_name: str,
+                 exchange: str,
                  credentials: PlainCredentials) -> None:
         self.host = host
         self.port = port
-        self.exchange_name: str = exchange_name
+        self.exchange: str = exchange
         self.credentials = credentials
         self.params = ConnectionParameters(host, port, '/', self.credentials)
 
@@ -18,6 +18,6 @@ class RabbitConfig:
     def from_dict(dictionary: dict[str, any]) -> 'RabbitConfig':
         host = dictionary['host']
         port = int(dictionary['port'])
-        exchange_name = dictionary['exchange_name']
+        exchange = dictionary['exchange']
         credentials = PlainCredentials(dictionary['user'], dictionary['pass'])
-        return RabbitConfig(host, port, exchange_name, credentials)
+        return RabbitConfig(host, port, exchange, credentials)
